@@ -1,6 +1,5 @@
 from __future__ import absolute_import
 
-import os
 import sys
 
 is_pypy = hasattr(sys, 'pypy_version_info')
@@ -13,12 +12,12 @@ else:
 
 if is_pypy:
     import _multiprocessing
-    from .compat import setblocking
+    from .compat import setblocking, send_offset
 
     class Connection(_multiprocessing.Connection):
 
-        def send_offset(self, buf, offset, write=os.write):
-            return write(self.fileno(), buf[offset:])
+        def send_offset(self, buf, offset):
+            return send_offset(self.fileno(), buf, offset)
 
         def setblocking(self, blocking):
             setblocking(self.fileno(), blocking)
